# Utilities for quick data generation:

# Simple function to generate X based on sample size/distribution
# samp = number of random draws
# dist = integer corresponding to desired distribution
	# 1: Uniform
	# 2: Exp. decreasing
	# 3: Normal
	# 4: wedge-shaped
	# 5: Exp. increasing
	# 6: bimodal
# m = min, M = max, b = changepoint
	# note: b is used only in calculating wedge.
xgen <- function(samp, dist, m = 0, M = 100, b = 50)
{
	prp <- M-m
	if(dist == 1)		x <- runif(samp, m, M)
	else if(dist == 2)	x <- m + rexp(samp,7.5)*prp
	else if(dist == 3)	{ x <- rnorm(samp); x <- ifelse(x < 0, m + prp/2 - prp/2*x/min(x), m + prp/2 + prp/2*x/max(x))}
	else if(dist == 4)	x <- rwedge(samp, m,b,M)
	else if(dist == 5)	x <- (1-rexp(samp,7.5))*prp + m
	else if(dist == 6)	x <- m + rbeta(samp,.25,.25)*prp
	return(x)
} # WARNING: distributions 2 and 5 occaasionally report out-of-bounds draws
#            this was handled outside of this code.



# Equally simple function to generate mu values based on inputs
# x = values along environmental gradient
# a = slope of mean after changepoint
# b = initial mean
# x0 = changepoint
# M = max
# note: though the code has an option to include a changepoint,
#	x0 was set to 0 in all sims.
mugen <- function(x, a, b, x0, M = 100)
{
	return(ifelse(x < x0, b, b*(1 + a*(x-x0)/(M-x0))))
}

# Function to randomly draw negative binomial samples from
# vectors of environmental gradients, means, and CVs
ygen <- function(x, mus, CV)
{
	return(rnbinom(length(x), mu = mus, size = (1+mus)/(mus*CV^2)))
}
