# Simple script to generate random datasets
# samps = vector of sampled site quantities
# slopes = vector of relative change of mean magnitudes
#	note: relative mean change from env = 0 to env = 100
# CV_range = vector of [min, max] CVs
# reps = number of replicates
# IV = initial mean of distribution

samps <- c(30,45,60,75,90,120,180,240,360,480,600)
slopes <- c(-.75, -.25, 0, .25, .75, 1.5)
CV_range <- c(.5,1.25)
reps <- 100
IV <- 50
dlist <- c("C", "Z", "M", "P", "O", "B")
cnt <- 0
tot <- length(samps)*length(slopes)*length(dlist)
# De-comment this to apply a randomized breakpoint
# 	used in exploratory work
# nlin_ratio: 1 = always, 0 = never
# nlin_ratio <- 0

for(samp in samps){ for(slope in slopes){ for(dist in 1:length(dlist)){
	tag <- paste(samp, slope, dlist[dist], sep = "_")
	X <- matrix(xgen(samp*reps,dist), reps, samp)
	CVs <- matrix(runif(reps,CV_range[1],CV_range[2]), reps, samp)
	#	Option to keep vary CVs 
	# CVs <- matrix(runif(samp*reps,CV_range[1],CV_range[2]), reps, samp)
	#	Option to apply random BPs
	# BPs <- matrix((runif(samp*reps) < nlin_ratio) * runif(samp*reps,0,100), reps, samp)
	BPs <- rep(0,reps*samp)
	Mus <- matrix(mugen(as.vector(X), slope, IV, as.vector(BPs)), reps, samp)
	Y <- matrix(ygen(as.vector(X), as.vector(Mus), as.vector(CVs)), reps, samp)
	write.table(X, file = paste("X_", tag, ".csv", sep = ""),
		sep = ",", row.names = F, col.names = F)
	write.table(Y, file = paste("Y_", tag, ".csv", sep = ""),
		sep = ",", row.names = F, col.names = F)
	write.table(CVs, file = paste(getwd(), "/parms/CV_", tag, ".csv", sep = ""),
		sep = ",", row.names = F, col.names = F)
	# write.table(BPs, file = paste(getwd(), "/parms/BP_", tag, ".csv", sep = ""),
		# sep = ",", row.names = F, col.names = F)
	cnt <- cnt+1
	cat("\nFinished: ", tag, ". ", round(cnt*100/tot,2), "% complete.\n", sep = "")
} } }
